@@ -1,18 +1,25 @@
 package org.gcube.portlets.widgets.fileupload.client.view;
 
-import org.gcube.portlets.widgets.fileupload.client.state.UploadProgressState;
+import org.gcube.portlets.widgets.fileupload.client.bundle.ProgressBarCssAndImages;
 
 import com.google.gwt.event.shared.HandlerManager;
 import com.google.gwt.user.client.ui.Composite;
+import com.google.gwt.user.client.ui.FileUpload;
 import com.google.gwt.user.client.ui.VerticalPanel;
-
+/**
+ * 
+ * @author Massimiliano Assante, ISTI-CNR
+ *
+ */
 public final class UploadProgressPanel extends Composite {
+	
+	static {
+		ProgressBarCssAndImages.INSTANCE.panelCss().ensureInjected();
+	}
 
 	private HandlerManager eventBus;
 
-
 	private FileSubmit fileSubmit;
-	private UploadProgress uploadProgress;
 	
 	private VerticalPanel mainPanel = new VerticalPanel();
 	
@@ -26,13 +33,20 @@ public final class UploadProgressPanel extends Composite {
 		initWidget(mainPanel);
 	}
 	
-	public void initialize() {	
+	public FileUpload initialize() {	
 		mainPanel.clear();
-		mainPanel.add(new FileSubmit(eventBus));
+		fileSubmit = new FileSubmit(eventBus);
+		mainPanel.add(fileSubmit);
 		mainPanel.add(new UploadProgress());
+		//return the fileupload so that you cane set it hidden
+		return fileSubmit.getFileUpload();
 	}
 
 	public void showRegisteringResult(boolean result) {
 		fileSubmit.showRegisteringResult(result);
 	}
+	
+	public FileUpload getFileUpload() {
+		return fileSubmit.getFileUpload();
+	}
 }
